@@ -11,10 +11,10 @@ more details.
 
 You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
 // "liveMedia"
-// Copyright (c) 1996-2008 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2010 Live Networks, Inc.  All rights reserved.
 // MPEG-1 or MPEG-2 Video RTP Sources
 // Implementation
 
@@ -56,7 +56,7 @@ Boolean MPEG1or2VideoRTPSource
 
   resultSpecialHeaderSize = 4;
   return True;
-}    
+}
 
 Boolean MPEG1or2VideoRTPSource
 ::packetIsUsableInJitterCalculation(unsigned char* packet,
@@ -74,7 +74,7 @@ Boolean MPEG1or2VideoRTPSource
   } else { // a P, B, D, or other unknown frame type
     return False;
   }
-}    
+}
 
 char const* MPEG1or2VideoRTPSource::MIMEtype() const {
   return "video/MPEG";
