@@ -13,7 +13,7 @@ You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
-// Copyright (c) 1996-2008, Live Networks, Inc.  All rights reserved
+// Copyright (c) 1996-2010, Live Networks, Inc.  All rights reserved
 // A subclass of "RTSPServer" that creates "ServerMediaSession"s on demand,
 // based on whether or not the specified stream name exists as a file
 // Implementation
@@ -80,7 +80,7 @@ DynamicRTSPServer::lookupServerMediaSession(char const* streamName) {
 }
 
 #define NEW_SMS(description) do {\
-char* descStr = description\
+char const* descStr = description\
     ", streamed by the LIVE555 Media Server";\
 sms = ServerMediaSession::createNew(env, fileName, fileName, descStr);\
 } while(0)
